@@ -10,6 +10,7 @@ from dataclasses import dataclass
 from typing import Optional, Dict
 from metricflow.cli.main import _print_issues
 from metricflow.model.parsing.config_linter import ConfigLinter
+from metricflow.model.parsing.dir_to_model import collect_yaml_config_file_paths
 from metricflow.model.validations.validator_helpers import ModelValidationResults
 
 EXPECTED_TF_CONFIG_FILE_NAMES = [
@@ -116,51 +117,25 @@ def _err_msg_from_err_response(r: requests.Response) -> str:
 
 
 def read_config_files(config_dir: str) -> Dict:  # noqa: D
-    try:
-        repo = git.Repo(config_dir, search_parent_directories=True)
-    except git.exc.InvalidGitRepositoryError:
-        repo = None
-
-    return _read_config_files(config_dir, repo)
-
-
-def _read_config_files(config_dir: str, git_repo: Optional[git.Repo]) -> Dict:
-    """Read yaml files from config_dir. Returns (file name, file contents) per file in dir"""
+    """Read yaml files from config_dir. Returns (file path, file contents) per file in dir"""
     assert os.path.exists(config_dir), f"User-specified config dir ({config_dir}) does not exist"
 
-    relative_file_paths = []
-    for path, _folders, filenames in os.walk(config_dir):
-        # This ensures we skip files in the dir's .git
-        # For reference we ran into an issue wherein a remote branch
-        # was named such that in ended in `.yaml`. And the branch metadata
-        # file in .git/logs/refs/remotes/origins was getting uploaded
-        # and causing parsing errors
-        if "/.git/" in path:
-            continue
-
-        for fname in filenames:
-            # ignore files that don't have a valid yaml extension
-            if not (fname.endswith(".yml") or fname.endswith(".yaml")):
-                continue
-
-            # ignore transform config
-            if fname in EXPECTED_TF_CONFIG_FILE_NAMES:
-                continue
-
-            relative_file_paths.append(os.path.join(path, fname))
-
-    # remove any .gitignore'd files
-    if git_repo:
-        ignored_files = git_repo.ignored(relative_file_paths)
-        relative_file_paths = list(set(relative_file_paths) - set(ignored_files))
+    relative_file_paths = collect_yaml_config_file_paths(directory=config_dir)
+    try:
+        git_repo = git.Repo(config_dir, search_parent_directories=True)
+    except git.exc.InvalidGitRepositoryError:
+        git_repo = None
 
     results = {}
-    repo_dir = git_repo.working_tree_dir if git_repo else None
     for relative_file_path in relative_file_paths:
+        # skip EXPECTED_TF_CONFIG_FILE_NAMES
+        if os.path.split(relative_file_path)[1] in EXPECTED_TF_CONFIG_FILE_NAMES:
+            continue
+
         with open(relative_file_path, "r") as f:
             filepath = os.path.abspath(relative_file_path)
-            if repo_dir is not None:
-                filepath = filepath.split(repo_dir)[-1]
+            if git_repo is not None:
+                filepath = filepath.split(git_repo.working_tree_dir)[-1]
             results[filepath] = f.read()
             try:
                 yaml.safe_load_all(results[filepath])
